#!/usr/bin/python3


def to_array(string):
    """Converts a string to an array relative to its spaces.

    Args:
        string (str): The string to convert into array

    Returns:
        str: New array
    """

    try:
        new_array = string.split(" ")  # Convert the string into array
        while "" in new_array:  # Check if the array contains empty strings
            new_array.remove("")
        return new_array
    except:
        print("The parameter string is not a str")
        return string


def to_point(string):
    """Replaces all the commas in a string with points.

    Args:
        string (str): String to change commas for points

    Returns:
        str: String with points
    """

    # Replace the commas with points in string
    try:
        string = string.replace(",", ".")
    except:
        print("The parameter string is not a str")
    finally:
        return string


def to_comma(string):
    """Replaces all the points in a string with commas.

    Args:
        string (str): String to change points for commas

    Returns:
        str: String with commas
    """

    # Replace the points with strings in string
    try:
        string = string.replace(".", ",")
    except:
        print("The parameter string is not a str")
    finally:
        return string



#!/usr/bin/python3

"""Add replace method improvements

Library to add some replace method improvements focused on
common replacements to optimize code.
"""

from .core import to_array, to_comma, to_point

__tittle__ = "improved replace"
__url__ = "https://github.com/LuckJMG/ImprovedReplace"
__author__ = "LuckJMG"
__email__ = "lucas.mosquera13@gmail.com"
__license__ = "MIT license"
__copyright__ = "Copyright 2020, LuckJMG"
__version__ = "1.3.1"
__status__ = "Production"
__all__ = ["to_array", "to_comma", "to_point"]



#!/usr/bin/python3
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="improved_replace",
    version="1.3.1",
    description="Add replace method improvements",
    url="https://github.com/LuckJMG/ImprovedReplace",
    author="LuckJMG",
    author_email="lucas.mosquera13@gmail.com",
    license="MIT license",
    long_description=long_description,
    platforms="OS Independent",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=["tests"]),
)
